Assorted spelling fixes

Francois Gouget fgouget at free.fr
Sat Apr 24 06:10:16 CDT 2004


Changelog:

 * dlls/advapi32/security.c
   dlls/d3d8/shader.c
   dlls/mapi32/prop.c
   dlls/mapi32/util.c
   documentation/bugs.sgml
   include/mapitags.h

   Assorted spelling fixes.


Index: dlls/advapi32/security.c
===================================================================
RCS file: /var/cvs/wine/dlls/advapi32/security.c,v
retrieving revision 1.66
diff -u -r1.66 security.c
--- a/dlls/advapi32/security.c	23 Apr 2004 21:32:34 -0000	1.66
+++ b/dlls/advapi32/security.c	24 Apr 2004 08:43:36 -0000
@@ -343,7 +343,7 @@
  * SetThreadToken [ADVAPI32.@]
  *
  * Assigns an 'impersonation token' to a thread so it can assume the
- * security privledges of another thread or process.  Can also remove
+ * security privileges of another thread or process.  Can also remove
  * a previously assigned token.
  *
  * PARAMS
Index: dlls/d3d8/shader.c
===================================================================
RCS file: /var/cvs/wine/dlls/d3d8/shader.c,v
retrieving revision 1.23
diff -u -r1.23 shader.c
--- a/dlls/d3d8/shader.c	23 Apr 2004 21:28:02 -0000	1.23
+++ b/dlls/d3d8/shader.c	24 Apr 2004 08:44:51 -0000
@@ -634,7 +634,7 @@
   /**
    * First pass to determine what we need to declare:
    *  - Temporary variables
-   *  - Adress variables
+   *  - Address variables
    */
   if (NULL != pToken) {
     while (D3DVS_END() != *pToken) {
@@ -735,7 +735,7 @@
 	for (i = 0; i < nUseAddressRegister; i++) {
             sprintf(tmpLine, "ADDRESS A%ld;\n", i);
 	    ++lineNum;
-            TRACE_(d3d_hw_shader)("GL HW (%u, %u) : %s", lineNum, strlen(pgmStr), tmpLine); /* Dont add /n to this line as already in tmpLine */
+            TRACE_(d3d_hw_shader)("GL HW (%u, %u) : %s", lineNum, strlen(pgmStr), tmpLine); /* Don't add \n to this line as already in tmpLine */
             strcat(pgmStr,tmpLine);
 	}
 	/* Due to the dynamic constants binding mechanism, we need to declare
@@ -743,7 +743,7 @@
 	/* Mesa supports only 95 constants for VS1.X although we should have at least 96.
 	 * Let's declare max constants minus one for now. */
 	sprintf(tmpLine, "PARAM C[%d] = { program.env[0..%d] };\n", numConstants-1, numConstants-2);
-	TRACE("GL HW (%u) : %s", strlen(pgmStr), tmpLine); /* Dont add /n to this line as already in tmpLine */
+	TRACE("GL HW (%u) : %s", strlen(pgmStr), tmpLine); /* Don't add \n to this line as already in tmpLine */
 	strcat(pgmStr, tmpLine);

 	++pToken;
Index: dlls/mapi32/util.c
===================================================================
RCS file: /var/cvs/wine/dlls/mapi32/util.c,v
retrieving revision 1.1
diff -u -r1.1 util.c
--- a/dlls/mapi32/util.c	23 Apr 2004 23:28:27 -0000	1.1
+++ b/dlls/mapi32/util.c	24 Apr 2004 08:39:38 -0000
@@ -330,7 +330,7 @@
  * Compare two Unicode strings.
  *
  * PARAMS
- *  dwCp      [I] Copde page for the comparason
+ *  dwCp      [I] Code page for the comparison
  *  lpszLeft  [I] First string to compare
  *  lpszRight [I] Second string to compare
  *
Index: documentation/bugs.sgml
===================================================================
RCS file: /var/cvs/wine/documentation/bugs.sgml,v
retrieving revision 1.21
diff -u -r1.21 bugs.sgml
--- a/documentation/bugs.sgml	20 Apr 2004 04:00:23 -0000	1.21
+++ b/documentation/bugs.sgml	24 Apr 2004 08:41:03 -0000
@@ -316,7 +316,7 @@
           </listitem>
           <listitem>
           <para>
-            Re-run the program with the WINEDEBUG enviroment variable <parameter>
+            Re-run the program with the WINEDEBUG environment variable <parameter>
             WINEDEBUG=+relay</parameter> option (i.e., <command>WINEDEBUG=+relay
             wine sol.exe</command>).
           </para>
Index: include/mapitags.h
===================================================================
RCS file: /var/cvs/wine/include/mapitags.h,v
retrieving revision 1.1
diff -u -r1.1 mapitags.h
--- a/include/mapitags.h	23 Apr 2004 23:28:04 -0000	1.1
+++ b/include/mapitags.h	24 Apr 2004 08:38:40 -0000
@@ -76,7 +76,7 @@
 #define PR_PRIORITY PROP_TAG(PT_I4,0x26)
 #define PR_ORIGIN_CHECK PROP_TAG(PT_BINARY,0x27)
 #define PR_PROOF_OF_SUBMISSION_REQUESTED PROP_TAG(PT_BOOLEAN,0x28)
-/* Whether a read reciept is desired */
+/* Whether a read receipt is desired */
 #define PR_READ_RECEIPT_REQUESTED PROP_TAG(PT_BOOLEAN,0x29)
 /* Time a message was received */
 #define PR_RECEIPT_TIME PROP_TAG(PT_SYSTIME,0x2A)
@@ -111,7 +111,7 @@
 #define PR_SUBJECT_PREFIX   WINELIB_NAME_AW(PR_SUBJECT_PREFIX_)
 #define PR_NON_RECEIPT_REASON PROP_TAG(PT_I4,0x3E)
 #define PR_RECEIVED_BY_ENTRYID PROP_TAG(PT_BINARY,0x3F)
-/* Recieved by: entry */
+/* Received by: entry */
 #define PR_RECEIVED_BY_NAME_W PROP_TAG(PT_UNICODE,0x40)
 #define PR_RECEIVED_BY_NAME_A PROP_TAG(PT_STRING8,0x40)
 #define PR_RECEIVED_BY_NAME   WINELIB_NAME_AW(PR_RECEIVED_BY_NAME_)



Index: dlls/mapi32/prop.c
===================================================================
RCS file: /var/cvs/wine/dlls/mapi32/prop.c,v
retrieving revision 1.1
diff -u -r1.1 prop.c
--- a/dlls/mapi32/prop.c	23 Apr 2004 23:28:27 -0000	1.1
+++ b/dlls/mapi32/prop.c	24 Apr 2004 08:39:14 -0000
@@ -385,11 +385,11 @@
  *
  * PARAMS
  *  lpPropLeft  [I] Left hand property to compare to lpPropRight
  *  ulOp        [I] Comparason operator (RELOP_* enum from "mapidefs.h")
  *  lpPropRight [I] Right hand property to compare to lpPropLeft
  *
  * RETURNS
  *  TRUE, if the comparason is true, FALSE otherwise.
  */
 BOOL WINAPI FPropCompareProp(LPSPropValue lpPropLeft, ULONG ulOp, LPSPropValue lpPropRight)
 {
@@ -402,7 +402,7 @@

     if (ulOp == RELOP_RE)
     {
-        FIXME("Comparason operator RELOP_RE not yet implemented!\n");
+        FIXME("Comparison operator RELOP_RE not yet implemented!\n");
         return FALSE;
     }
@@ -385,11 +385,11 @@
  * PARAMS
  *  lpPropLeft  [I] Left hand property to compare to lpPropRight
- *  ulOp        [I] Comparason operator (RELOP_* enum from "mapidefs.h")
+ *  ulOp        [I] Comparison operator (RELOP_* enum from "mapidefs.h")
  *  lpPropRight [I] Right hand property to compare to lpPropLeft
  *
@@ -385,11 +385,11 @@
  *
  * RETURNS
- *  TRUE, if the comparason is true, FALSE otherwise.
+ *  TRUE, if the comparison is true, FALSE otherwise.
  */
 BOOL WINAPI FPropCompareProp(LPSPropValue lpPropLeft, ULONG ulOp, LPSPropValue lpPropRight)

-- 
Francois Gouget         fgouget at free.fr        http://fgouget.free.fr/
                      Computers are like airconditioners
                They stop working properly if you open WINDOWS



More information about the wine-patches mailing list